@@ -8,22 +8,22 @@ OC.L10N.register(
     "Rename" : "Hernoem",
     "Copy link" : "Kopieer skakel",
     "Move" : "Skuif",
-    "Delete" : "Skrap",
     "Select all" : "Kies alle",
     "Go back" : "Gaan terug",
     "New" : "Nuut",
     "New folder" : "Nuwe vouer",
     "Search" : "Soek",
     "Add a bookmark" : "Voeg 'n boekmerk by",
-    "Delete folder" : "Skrap vouer",
     "Choose folder" : "Kies vouer",
     "Submit" : "Dien in",
     "Cancel" : "Kanselleer",
     "Recent" : "Onlangs",
     "Shared with you" : "Met u gedeel",
     "Files" : " Lêers",
+    "Delete" : "Skrap",
     "Settings" : "Instellings",
     "Bookmarklet" : "Boekmerkie",
+    "Need help?" : "Hulp nodig?",
     "Title" : "Titel",
     "Link" : "Skakel",
     "Tags" : "Merkers",
