@@ -5,20 +5,20 @@ OC.L10N.register(
     "Rename" : "Adenvel",
     "Copy link" : "Kopiañ al liamm",
     "Move" : "Diplasañ",
-    "Delete" : "Dilemel",
     "Select all" : "Dibab pep tra",
     "New" : "Nevez",
     "New folder" : "Heuliad nevez",
     "Search" : "Klask",
     "Sort by created date" : "Renkañ dre deizat krouidigezh",
-    "Delete folder" : "Dilemel an teuliad",
     "Submit" : "Kinnig",
     "Cancel" : "Arrest",
     "Recent" : "Nevez",
     "Shared with you" : "Rannet ganeoc'h",
     "Files" : "Restroù",
     "Broken links" : "Liammoù toret",
+    "Delete" : "Dilemel",
     "Settings" : "Arventennoù",
+    "Need help?" : "Sikour o po ?",
     "Title" : "Titl",
     "Link" : "Liamm",
     "Tags" : "Klavioù",
