@@ -44,7 +44,6 @@ OC.L10N.register(
     "Rename" : "Μετονομασία",
     "Copy link" : "Αντιγραφή συνδέσμου",
     "Move" : "Μετακίνηση",
-    "Delete" : "Διαγραφή",
     "Do you really want to delete this bookmark?" : "Θέλετε πραγματικά να διαγράψετε αυτόν τον σελιδοδείκτη;",
     "Link copied to clipboard" : "Ο σύνδεσμος αντιγράφηκε στο πρόχειρο",
     "Open all selected" : "Άνοιγμα των επιλεγμένων",
@@ -86,8 +85,6 @@ OC.L10N.register(
     "Shared by {user}" : "Διαμοιράστηκε από {user}",
     "Rename folder" : "Μετονομασία φακέλου",
     "Move folder" : "Μετακίνηση φακέλου",
-    "Delete folder" : "Διαγραφή φακέλου",
-    "Do you really want to delete this folder?" : "Θέλετε πραγματικά να διαγράψετε αυτόν τον φάκελο;",
     "Choose folder" : "Επιλογή φακέλου",
     "Submit" : "Υποβολή",
     "Cancel" : "Ακύρωση",
@@ -105,6 +102,7 @@ OC.L10N.register(
     "Broken links" : "Κατεστραμμένοι σύνδεσμοι",
     "New tag" : "Νέα ετικέτα",
     "Search tags" : "Ετικέτες αναζήτησης",
+    "Delete" : "Διαγραφή",
     "Untagged" : "Χωρίς ετικέτα",
     "{used} bookmarks of {available} available" : "Διαθέσιμοι  {available} σελιδοδείκτες από {used}",
     "Settings" : "Ρυθμίσεις",
