@@ -46,7 +46,6 @@ OC.L10N.register(
     "Copy link" : "Hivatkozás másolása",
     "Move" : "Áthelyezés",
     "Add to folders" : "Hozzáadás a mappákhoz",
-    "Delete" : "Törlés",
     "Do you really want to delete this bookmark?" : "Biztos, hogy törli ezt a könyvjelzőt?",
     "Link copied to clipboard" : "Hivatkozás a vágólapra másolva",
     "Content pending" : "Tartalom függőben",
@@ -102,8 +101,6 @@ OC.L10N.register(
     "Shared by {user}" : "Megosztotta: {user}",
     "Rename folder" : "Mappa átnevezése",
     "Move folder" : "Mappa áthelyezése",
-    "Delete folder" : "Mappa törlése",
-    "Do you really want to delete this folder?" : "Biztos, hogy törli ezt a mappát?",
     "Choose folder" : "Válasszon mappát",
     "Submit" : "Beküldés",
     "Cancel" : "Mégse",
@@ -123,6 +120,7 @@ OC.L10N.register(
     "Broken links" : "Megszakadt hivatkozások",
     "New tag" : "Új címke",
     "Search tags" : "Címkék keresése",
+    "Delete" : "Törlés",
     "Untagged" : "Nem címkézett",
     "{used} bookmarks of {available} available" : "{used} könyvjelző / {available} elérhető",
     "Settings" : "Beállítások",
@@ -143,6 +141,7 @@ OC.L10N.register(
     "Bookmarklet" : "Bookmarklet",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Húzza ezt a böngésző könyvjelzőihez, és kattintson rá a weboldal gyors könyvjelzőzéséhez.",
     "Add to {instanceName}" : "Hozzáadás ehhez: {instanceName}",
+    "Need help?" : "Segítségre van szüksége?",
     "Archive path" : "Archívum elérési útvonala",
     "Backup path" : "Biztonsági mentés útvonala",
     "Please select \"Add to home screen\" in your browser menu" : "Válassza a böngésző menüjében a „Hozzáadás a kezdőképernyőhöz” lehetőséget",
