@@ -11,7 +11,6 @@ OC.L10N.register(
     "Rename" : "Endurnefna",
     "Copy link" : "Afrita tengil",
     "Move" : "Færa",
-    "Delete" : "Eyða",
     "Link copied to clipboard" : "Tengill afritaður á klippispjald",
     "Open all selected" : "Opna allt valið",
     "Move selection" : "Færa valið",
@@ -35,7 +34,6 @@ OC.L10N.register(
     "Enter folder title" : "Settu inn heiti möppu",
     "Shared by {user}" : "Deilt af {user}",
     "Rename folder" : "Endurnefna möppu",
-    "Delete folder" : "Eyða möppu",
     "Choose folder" : "Veldu möppu",
     "Submit" : "Senda inn",
     "Cancel" : "Hætta við",
@@ -46,6 +44,7 @@ OC.L10N.register(
     "Recent" : "Nýlegt",
     "Shared with you" : "Deilt með þér",
     "Files" : "Skrár",
+    "Delete" : "Eyða",
     "Untagged" : "Ómerkt",
     "{used} bookmarks of {available} available" : "{used} bókamerki af {available} tiltækum",
     "Settings" : "Stillingar",
@@ -54,6 +53,7 @@ OC.L10N.register(
     "Also check out the collection of client apps that integrate with this app: " : "Skoðaðu einnig úrval þeirra biðlaraforrita sem samþættast þessu forriti:",
     "Bookmarklet" : "Bókamerklingur",
     "Add to {instanceName}" : "Bæta við {instanceName}",
+    "Need help?" : "Þarftu hjálp?",
     "Title" : "Titill",
     "Link" : "Tengill",
     "Root folder" : "Rótarmappa",
