@@ -45,7 +45,6 @@ OC.L10N.register(
     "Copy link" : "リンクをコピー",
     "Move" : "移動",
     "Add to folders" : "フォルダーに追加",
-    "Delete" : "削除",
     "Do you really want to delete this bookmark?" : "本当にこのブックマークを削除しますか？",
     "Link copied to clipboard" : "クリップボードにリンクをコピーしました",
     "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "ウェブ上の写真やPDFといったファイルへのブックマークは、自動的にNextcloudファイルとして保存されるため、リンクがオフラインになっても見つけることができます。",
@@ -87,8 +86,6 @@ OC.L10N.register(
     "Shared by {user}" : "{user} から共有されました",
     "Rename folder" : "フォルダーの名前を変更",
     "Move folder" : "フォルダーを移動",
-    "Delete folder" : "フォルダーを削除",
-    "Do you really want to delete this folder?" : "本当にこのフォルダーを削除しますか？",
     "Choose folder" : "フォルダーを選択",
     "Submit" : "送信",
     "Cancel" : "キャンセル",
@@ -106,6 +103,7 @@ OC.L10N.register(
     "Broken links" : "壊れたリンク",
     "New tag" : "新しいタグ",
     "Search tags" : "タグを検索",
+    "Delete" : "削除",
     "Untagged" : "タグなし",
     "{used} bookmarks of {available} available" : "利用可能ブックマーク数 {available} のうち{used} が使用済み ",
     "Settings" : "設定",
@@ -119,6 +117,7 @@ OC.L10N.register(
     "Install on home screen" : "ホーム画面へインストール",
     "Bookmarklet" : "ブックマークレット",
     "Add to {instanceName}" : "{instanceName}に追加",
+    "Need help?" : "ヘルプが必要ですか？",
     "Archive path" : "アーカイブパス",
     "Please select \"Add to home screen\" in your browser menu" : "お使いのブラウザーで「ホーム画面に追加」を選択してください",
     "Title" : "タイトル",
