@@ -8,7 +8,6 @@ OC.L10N.register(
     "Rename" : "სახელის შეცვლა",
     "Copy link" : "ბმულის კოპირება",
     "Move" : "გადატანა",
-    "Delete" : "წაშლა",
     "Select all" : "ყველას არჩევა",
     "Go back" : "უკან დაბრუნება",
     "New" : "ახალი",
@@ -16,15 +15,16 @@ OC.L10N.register(
     "Search" : "ძიება",
     "Add a bookmark" : "სანიშნის დამატება",
     "Rename folder" : "ფოლდერის სახელის გადარქმევა",
-    "Delete folder" : "დირექტორიის გაუქმება",
     "Choose folder" : "აირჩიეთ დირექტორია",
     "Submit" : "გაგზავნა",
     "Cancel" : "უარყოფა",
     "Recent" : "ახალი",
     "Shared with you" : "გაზიარებული თქვენთან",
     "Files" : "ფაილები",
+    "Delete" : "წაშლა",
     "Settings" : "პარამეტრები",
     "Bookmarklet" : "Bookmarklet-ი",
+    "Need help?" : "გესაჭიროებათ დახმარება?",
     "Title" : "სათაური",
     "Link" : "ბმული",
     "Tags" : "ტეგები",
