@@ -23,7 +23,6 @@ OC.L10N.register(
     "Rename" : "Pervadinti",
     "Copy link" : "Kopijuoti nuorodą",
     "Move" : "Perkelti",
-    "Delete" : "Ištrinti",
     "Link copied to clipboard" : "Nuoroda nukopijuota į iškarpinę",
     "Move selection" : "Perkelti žymėjimą",
     "Delete selection" : "Ištrinti žymėjimą",
@@ -44,8 +43,6 @@ OC.L10N.register(
     "Shared by {user}" : "Bendrina {user}",
     "Rename folder" : "Pervadinti aplanką",
     "Move folder" : "Perkelti aplanką",
-    "Delete folder" : "Ištrinti aplanką",
-    "Do you really want to delete this folder?" : "Ar tikrai norite ištrinti šį aplanką?",
     "Choose folder" : "Pasirinkti aplanką",
     "Submit" : "Pateikti",
     "Cancel" : "Atsisakyti",
@@ -56,11 +53,13 @@ OC.L10N.register(
     "Shared with you" : "Bendrinama su jumis",
     "Files" : "Failai",
     "New tag" : "Nauja žymė",
+    "Delete" : "Ištrinti",
     "Untagged" : "Be žymių",
     "Settings" : "Nustatymai",
     "No bookmarks here" : "Čia adresyno įrašų nėra",
     "Client apps" : "Kliento programėlės",
     "Add to {instanceName}" : "Pridėti į {instanceName}",
+    "Need help?" : "Reikia pagalbos?",
     "Title" : "Pareigos",
     "Link" : "Nuoroda",
     "Root folder" : "Šakninis aplankas",
