@@ -9,7 +9,6 @@ OC.L10N.register(
     "Rename" : "Pārsaukt",
     "Copy link" : "Kopēt saiti",
     "Move" : "Pārvietot",
-    "Delete" : "Dzēst",
     "Select all" : "Atzīmēt visu",
     "Go back" : "Atpakaļ",
     "New" : "Jauns",
@@ -17,15 +16,16 @@ OC.L10N.register(
     "Search" : "Meklēt",
     "Add a bookmark" : "Pievienot grāmatzīmi",
     "Rename folder" : "Pārsaukt mapi",
-    "Delete folder" : "Dzēst mapi",
     "Choose folder" : "Izvēlies mapi",
     "Submit" : "Iesniegt",
     "Cancel" : "Atcelt",
     "Recent" : "Nesenās",
     "Shared with you" : "Koplietots ar jums",
     "Files" : "Datnes",
+    "Delete" : "Dzēst",
     "Settings" : "Iestatījumi",
     "Bookmarklet" : "Grāmatzīme",
+    "Need help?" : "Vajadzīga palīdzība?",
     "Title" : "Amats",
     "Link" : "Saite",
     "Tags" : "Birkas",
