@@ -45,7 +45,6 @@ OC.L10N.register(
     "Copy link" : "Link kopiëren",
     "Move" : "Verplaatsen",
     "Add to folders" : "Voeg toe aan mappen",
-    "Delete" : "Verwijderen",
     "Do you really want to delete this bookmark?" : "Wil je deze bladwijzer echt verwijderen?",
     "Link copied to clipboard" : "Link gekopieerd naar het klembord",
     "Content pending" : "Content in behandeling",
@@ -93,8 +92,6 @@ OC.L10N.register(
     "Shared by {user}" : "Gedeeld door {user}",
     "Rename folder" : "Hernoem map",
     "Move folder" : "Verplaatsen map",
-    "Delete folder" : "Verwijder map",
-    "Do you really want to delete this folder?" : "Wil je deze map echt verwijderen?",
     "Choose folder" : "Kies map",
     "Submit" : "Verwerken",
     "Cancel" : "Annuleren",
@@ -114,6 +111,7 @@ OC.L10N.register(
     "Broken links" : "Niet-werkende links",
     "New tag" : "Nieuwe tag",
     "Search tags" : "Zoek in tags",
+    "Delete" : "Verwijderen",
     "Untagged" : "Niet getagd",
     "{used} bookmarks of {available} available" : "{used} bladwijzers van {available} beschikbare",
     "Settings" : "Instellingen",
@@ -130,6 +128,7 @@ OC.L10N.register(
     "Bookmarklet" : "Bookmarklet",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Sleep dit naar je browser bladwijzers en open het om snel een bladwijzer van een website te maken.",
     "Add to {instanceName}" : "Toevoegen aan {instanceName}",
+    "Need help?" : "Hulp nodig?",
     "Archive path" : "Archief pad",
     "Backup path" : "Back-up pad",
     "Please select \"Add to home screen\" in your browser menu" : "Selecteer 'Voeg toe aan thuisscherm' in je browser menu",
