@@ -46,7 +46,6 @@ OC.L10N.register(
     "Copy link" : "Kopiraj povezavo",
     "Move" : "Premakni",
     "Add to folders" : "Dodaj med mape",
-    "Delete" : "Izbriši",
     "Do you really want to delete this bookmark?" : "Ali ste prepričani, da želite izbrisati ta zaznamek?",
     "Link copied to clipboard" : "Povezava je kopirana v odložišče",
     "Content pending" : "Vsebina na čakanju",
@@ -102,8 +101,6 @@ OC.L10N.register(
     "Shared by {user}" : "V skupni rabi z {user}",
     "Rename folder" : "Preimenuj mapo",
     "Move folder" : "Premakni mapo",
-    "Delete folder" : "Izbriši mapo",
-    "Do you really want to delete this folder?" : "Ali ste prepričani, da želite izbrisati to mapo?",
     "Choose folder" : "Izbor mape",
     "Submit" : "Pošlji",
     "Cancel" : "Prekliči",
@@ -123,6 +120,7 @@ OC.L10N.register(
     "Broken links" : "Okvarjene povezave",
     "New tag" : "Nova oznaka",
     "Search tags" : "Poišči oznake",
+    "Delete" : "Izbriši",
     "Untagged" : "Neoznačeno",
     "{used} bookmarks of {available} available" : "Uporabljeno {used} od razpoložljivih {available}",
     "Settings" : "Nastavitve",
@@ -143,6 +141,7 @@ OC.L10N.register(
     "Bookmarklet" : "Program za zaznamke",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Potegnite to med zaznamke brskalnika in kliknite za hitro dodajanje zaznamka spletne strani.",
     "Add to {instanceName}" : "Dodaj {instanceName} ",
+    "Need help?" : "Ali potrebujete pomoč?",
     "Archive path" : "Arhiviraj pot",
     "Backup path" : "Varnostna kopija poti",
     "Please select \"Add to home screen\" in your browser menu" : "V meniju brskalnika izberite možnost »Dodaj na začetni zaslon«",
