@@ -46,13 +46,16 @@ OC.L10N.register(
     "Copy link" : "Kopiera länk",
     "Move" : "Flytta",
     "Add to folders" : "Lägg till i mappar",
-    "Delete" : "Ta bort",
+    "Put bookmark into trash bin" : "Lägg bokmärket i papperskorgen",
+    "Restore bookmark" : "Återställ bokmärke",
+    "Delete bookmark permanently" : "Ta bort bokmärke permanent",
     "Do you really want to delete this bookmark?" : "Är du säker att du vill ta bort detta bokmärket?",
     "Link copied to clipboard" : "Länken kopierad till urklipp",
     "Content pending" : "Innehåll förestår",
     "This content is being downloaded for offline use. Please check back later." : "Detta innehåll laddas ner för offlineanvändning. Vänligen försök igen senare.",
     "Bookmarked {time} ago" : "Sparad för {time} sedan",
     "Bookmarked on {date}" : "Sparad den {date}",
+    "These are your deleted items." : "Det här är dina raderade objekt.",
     "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmärken till filer på webben som foton eller PDF-filer sparas automatiskt till dina Nextcloud-filer, så att du fortfarande kan hitta dem även när länken går offline.",
     "Searching in the current folder only." : "Söker endast i nuvarande mappen.",
     "Repeat search in all folders" : "Upprepa sökning i alla mappar",
@@ -69,6 +72,7 @@ OC.L10N.register(
     "Do you really want to delete these items?" : "Är du säker att du vill ta bort dessa objekt?",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valde %n bokmärke","Valde %n bokmärken"],
     "_Selected %n folder_::_Selected %n folders_" : ["Valde %n mapp","Valde %n mappar"],
+    "Trash Bin" : "Papperskorg",
     "Go back" : "Gå tillbaks",
     "Share folder" : "Dela mapp",
     "Select one or more tags" : "Välj en eller flera taggar",
@@ -103,8 +107,10 @@ OC.L10N.register(
     "Shared by {user}" : "Delad av {user}",
     "Rename folder" : "Byt namn på mapp",
     "Move folder" : "Flytta mapp",
-    "Delete folder" : "Ta bort mapp",
-    "Do you really want to delete this folder?" : "Är du säker att du vill ta bort denna mappen?",
+    "Put folder into trashbin" : "Lägg mappen i papperskorgen",
+    "Restore folder" : "Återställ mapp",
+    "Delete folder permanently" : "Ta bort mapp permanent",
+    "Do you really want to permanently delete this folder?" : "Vill du verkligen ta bort den här mappen permanent?",
     "Choose folder" : "Välj mapp",
     "Submit" : "Skicka",
     "Cancel" : "Avbryt",
@@ -124,6 +130,7 @@ OC.L10N.register(
     "Broken links" : "Brutna länkar",
     "New tag" : "Ny tagg",
     "Search tags" : "Sök taggar",
+    "Delete" : "Ta bort",
     "Untagged" : "Inte taggad",
     "{used} bookmarks of {available} available" : "{used} bokmärken av {available} tillgängliga",
     "Settings" : "Inställningar",
@@ -134,6 +141,8 @@ OC.L10N.register(
     "No broken links" : "Inga trasiga länkar",
     "No shared folders" : "Inga delade mappar",
     "No duplicated bookmarks" : "Inga dubblerade bokmärken",
+    "No deleted bookmarks" : "Inga borttagna bokmärken",
+    "You haven't deleted anything yet." : "Du har inte tagit bort något ännu.",
     "No bookmarks here" : "Inga bokmärken här",
     "Add bookmarks manually or import bookmarks from a HTML file." : "Lägg till bokmärken manuellt eller importera bokmärken från en HTML-fil.",
     "Bookmarks settings" : "Bokmärkesinställningar",
@@ -155,6 +164,9 @@ OC.L10N.register(
     "Bookmarklet" : "Bookmarklet",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Dra till webbläsarens bokmärken och klicka på den för att snabbt bokmärka en webbplats.",
     "Add to {instanceName}" : "Lägg till {instanceName}",
+    "Need help?" : "Behövs hjälp?",
+    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Om du har problem med denna bokmärkesapp eller har en idé om vad som kan förbättras, tveka inte att höra av dig genom att klicka här.",
+    "Support this project" : "Stöd detta projekt",
     "Archive path" : "Sökväg till arkiv",
     "Backup path" : "Sökväg till säkerhetskopior",
     "Please select \"Add to home screen\" in your browser menu" : "Vänligen välj \"Lägg till hemskärm\" i din webbläsarmeny",
@@ -228,7 +240,9 @@ OC.L10N.register(
     "Failed to rename tag" : "Kunde inte döpa om tagg",
     "Failed to load tags" : "Kunde inte läsa in taggar",
     "Failed to load folders" : "Kunde inte läsa in mappar",
+    "Failed to load deleted bookmarks" : "Kunde inte läsa in borttagna bokmärken",
     "Failed to delete folder" : "Kunde inte radera mapp",
+    "Failed to move folder" : "Det gick inte att flytta mappen",
     "Failed to create folder" : "Kunde inte skapa mapp",
     "Failed to fetch bookmarks." : "Kunde inte hämta bokmärken.",
     "Failed to store setting" : "Kunde inte spara inställning",
