@@ -8,7 +8,6 @@ OC.L10N.register(
     "Rename" : "Перейменувати",
     "Copy link" : "Копіювати посилання",
     "Move" : "Перемістити",
-    "Delete" : "Вилучити",
     "Link copied to clipboard" : "Посилання скопійовано в буфер обміну",
     "This content is being downloaded for offline use. Please check back later." : "Вміст звантажується для використання в автономному режимі. Будь ласка, перевірте пізніше.",
     "Delete selection" : "Прибрати виділення",
@@ -27,13 +26,14 @@ OC.L10N.register(
     "Add a bookmark" : "Додати закладку",
     "Shared by {user}" : "{user} надав(-ла) доступ",
     "Rename folder" : "Перейменувати каталог",
-    "Delete folder" : "Вилучити каталог",
     "Submit" : "Гаразд",
     "Cancel" : "Скасувати",
     "Recent" : "Нещодавні",
     "Shared with you" : "Вам надано доступ",
     "Files" : "Робота з файлами",
+    "Delete" : "Вилучити",
     "Settings" : "Налаштування",
+    "Need help?" : "Потрібна допомога?",
     "Title" : "Назва",
     "Link" : "Посилання",
     "Root folder" : "Кореневий каталог",
