@@ -47,13 +47,16 @@ OC.L10N.register(
     "Copy link" : "複製連結",
     "Move" : "移動",
     "Add to folders" : "新增至資料夾",
-    "Delete" : "刪除",
+    "Put bookmark into trash bin" : "將書籤放到垃圾桶中",
+    "Restore bookmark" : "還原書籤",
+    "Delete bookmark permanently" : "永久刪除書籤",
     "Do you really want to delete this bookmark?" : "您確定要刪除此標籤嗎？",
     "Link copied to clipboard" : "已複製連結至剪貼簿",
     "Content pending" : "內容待定",
     "This content is being downloaded for offline use. Please check back later." : "此內容已下載供離線使用。請稍後再檢查。",
     "Bookmarked {time} ago" : "{time} 前加入書籤",
     "Bookmarked on {date}" : "於 {date} 加入書籤",
+    "These are your deleted items." : "這些是您刪除的項目。",
     "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "網路上的檔案（如照片或 PDF 等）的書籤將會自動儲存到您的 Nextcloud 檔案中，因此即便連結離線，您也仍然可以找到它們。",
     "Searching in the current folder only." : "僅在目前資料夾中搜尋。",
     "Repeat search in all folders" : "在所有資料夾中重複搜尋",
@@ -70,6 +73,7 @@ OC.L10N.register(
     "Do you really want to delete these items?" : "您想要刪除這些項目嗎？",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["已選取 %n 書籤"],
     "_Selected %n folder_::_Selected %n folders_" : ["已選取%n個資料夾"],
+    "Trash Bin" : "垃圾桶",
     "Go back" : "返回",
     "Share folder" : "分享資料夾",
     "Select one or more tags" : "選取一個或更多標籤",
@@ -105,8 +109,10 @@ OC.L10N.register(
     "Shared by {user}" : "由 {user} 分享",
     "Rename folder" : "資料夾更名",
     "Move folder" : "移動資料夾",
-    "Delete folder" : "刪除資料夾",
-    "Do you really want to delete this folder?" : "您真的想要刪除此資料夾嗎？",
+    "Put folder into trashbin" : "將資料夾放到垃圾桶中",
+    "Restore folder" : "還原資料夾",
+    "Delete folder permanently" : "永久刪除資料夾",
+    "Do you really want to permanently delete this folder?" : "您真的想要永久刪除此資料夾嗎？",
     "Choose folder" : "選擇資料夾",
     "Submit" : "送出",
     "Cancel" : "取消",
@@ -126,6 +132,7 @@ OC.L10N.register(
     "Broken links" : "連結損毀",
     "New tag" : "新標籤",
     "Search tags" : "搜尋標籤",
+    "Delete" : "刪除",
     "Untagged" : "無標籤",
     "{used} bookmarks of {available} available" : "{used} 書籤，可用 {available}",
     "Settings" : "設定",
@@ -136,6 +143,8 @@ OC.L10N.register(
     "No broken links" : "沒有失效的連結",
     "No shared folders" : "沒有已分享的資料夾",
     "No duplicated bookmarks" : "沒有重複的書籤",
+    "No deleted bookmarks" : "沒有已刪除的書籤",
+    "You haven't deleted anything yet." : "您尚未刪除任何東西。",
     "No bookmarks here" : "此處無書籤",
     "Add bookmarks manually or import bookmarks from a HTML file." : "手動新增書籤或從 HTML 檔案匯入。",
     "Bookmarks settings" : "書籤設定",
@@ -157,6 +166,10 @@ OC.L10N.register(
     "Bookmarklet" : "書籤",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "將這個拖曳到您的瀏覽器書籤中，並點擊它以快速將網頁加入書籤。",
     "Add to {instanceName}" : "新增到 {instanceName}",
+    "Need help?" : "需要協助嗎？",
+    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "若您在使用此書籤應用程式時遇到問題或有任何關於改進的想法，請隨時按此處與我們聯絡。",
+    "Support this project" : "支援此專案",
+    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "我在這個書籤應用程式上的工作是由自願訂閱模式推動的。如果您覺得我的工作有價值並支援我的工作，我會非常高興。另外，請考慮在 Nextcloud 應用程式商店上對該應用程式進行評論。謝謝你💙",
     "Archive path" : "封存路徑",
     "Backup path" : "備份路徑",
     "Please select \"Add to home screen\" in your browser menu" : "請在您的瀏覽器選單中選取「新增至主畫面」",
@@ -216,8 +229,6 @@ OC.L10N.register(
     "Save" : "儲存",
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "預設情況下停用網路存取。到管理設定中讓書籤應用程式可以擷取預覽與 favicon。",
     "What's new?" : "有什麼新鮮事？",
-    "Support this project?" : "支援此專案？",
-    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "我在這個書籤應用程式上的工作是由自願訂閱模式推動的。如果您覺得我的工作有價值並支援我的工作，我會非常高興。另外，請考慮在 Nextcloud 應用程式商店上對該應用程式進行評論。謝謝你💙",
     "What" : "什麼",
     "Failed to count unavailable bookmarks" : "計算不可用的書籤失敗",
     "Failed to count archived bookmarks" : "計算已封存的書籤失敗",
@@ -232,7 +243,9 @@ OC.L10N.register(
     "Failed to rename tag" : "重新命名標籤失敗",
     "Failed to load tags" : "載入標籤失敗",
     "Failed to load folders" : "載入資料夾失敗",
+    "Failed to load deleted bookmarks" : "載入已刪除的書籤失敗",
     "Failed to delete folder" : "刪除資料夾失敗",
+    "Failed to move folder" : "移動資料夾失敗",
     "Failed to create folder" : "建立資料夾失敗",
     "Failed to fetch bookmarks." : "擷取書籤失敗",
     "Failed to store setting" : "儲存設定失敗",
