@@ -69,10 +69,20 @@ class InternalFoldersController extends ApiController {
 	 *
 	 * @NoAdminRequired
 	 */
-	public function deleteFolder($folderId): JSONResponse {
+	public function deleteFolder(int $folderId): JSONResponse {
 		return $this->controller->deleteFolder($folderId);
 	}
 
+	/**
+	 * @param int $folderId
+	 * @return JSONResponse
+	 *
+	 * @NoAdminRequired
+	 */
+	public function undeleteFolder(int $folderId): JSONResponse {
+		return $this->controller->undeleteFolder($folderId);
+	}
+
 	/**
 	 * @param int $folderId
 	 * @param int $bookmarkId
@@ -95,6 +105,17 @@ class InternalFoldersController extends ApiController {
 		return $this->controller->removeFromFolder($folderId, $bookmarkId);
 	}
 
+	/**
+	 * @param int $folderId
+	 * @param int $bookmarkId
+	 * @return JSONResponse
+	 *
+	 * @NoAdminRequired
+	 */
+	public function undeleteFromFolder(int $folderId, int $bookmarkId): JSONResponse {
+		return $this->controller->undeleteFromFolder($folderId, $bookmarkId);
+	}
+
 	/**
 	 * @param int $folderId
 	 * @param string|null $title
@@ -221,4 +242,13 @@ class InternalFoldersController extends ApiController {
 	public function deleteShare($shareId): DataResponse {
 		return $this->controller->deleteShare($shareId);
 	}
+
+	/**
+	 * @return DataResponse
+	 * @NoAdminRequired
+	 * @NoCSRFRequired
+	 */
+	public function getDeletedFolders(): DataResponse {
+		return $this->controller->getDeletedFolders();
+	}
 }
