@@ -12,6 +12,7 @@ use OCA\Bookmarks\Db\Folder;
 use OCA\Bookmarks\Db\FolderMapper;
 use OCA\Bookmarks\Db\SharedFolderMapper;
 use OCA\Bookmarks\Db\ShareMapper;
+use OCA\Bookmarks\Db\TagMapper;
 use OCA\Bookmarks\Db\TreeMapper;
 use OCA\Bookmarks\Events\ChangeEvent;
 use OCA\Bookmarks\Events\MoveEvent;
@@ -25,34 +26,19 @@ use OCP\ICacheFactory;
 use Psr\Container\ContainerInterface;
 use UnexpectedValueException;
 
+/**
+ * @psalm-implements IEventListener<ChangeEvent>
+ */
 class TreeCacheManager implements IEventListener {
+	public const TTL = 60 * 60 * 24 * 30; // one month
 	public const CATEGORY_HASH = 'hashes';
 	public const CATEGORY_SUBFOLDERS = 'subFolders';
+	public const CATEGORY_DELETED_SUBFOLDERS = 'deletedSubFolders';
 	public const CATEGORY_FOLDERCOUNT = 'folderCount';
 	public const CATEGORY_CHILDREN = 'children';
 	public const CATEGORY_CHILDREN_LAYER = 'children_layer';
 	public const CATEGORY_CHILDORDER = 'childOrder';
 
-	/**
-	 * @var BookmarkMapper
-	 */
-	protected $bookmarkMapper;
-	/**
-	 * @var ShareMapper
-	 */
-	protected $shareMapper;
-	/**
-	 * @var SharedFolderMapper
-	 */
-	protected $sharedFolderMapper;
-	/**
-	 * @var TreeMapper
-	 */
-	protected $treeMapper;
-	/**
-	 * @var FolderMapper
-	 */
-	protected $folderMapper;
 	/**
 	 * @var bool
 	 */
@@ -62,11 +48,6 @@ class TreeCacheManager implements IEventListener {
 	 * @var ICache[]
 	 */
 	private $caches = [];
-	private ContainerInterface $appContainer;
-	/**
-	 * @var \OCA\Bookmarks\Db\TagMapper
-	 */
-	private $tagMapper;
 
 	/**
 	 * FolderMapper constructor.
@@ -77,21 +58,24 @@ class TreeCacheManager implements IEventListener {
 	 * @param SharedFolderMapper $sharedFolderMapper
 	 * @param ICacheFactory $cacheFactory
 	 * @param ContainerInterface $appContainer
-	 * @param \OCA\Bookmarks\Db\TagMapper $tagMapper
+	 * @param TagMapper $tagMapper
 	 */
-	public function __construct(FolderMapper $folderMapper, BookmarkMapper $bookmarkMapper, ShareMapper $shareMapper, SharedFolderMapper $sharedFolderMapper, ICacheFactory $cacheFactory, ContainerInterface $appContainer, \OCA\Bookmarks\Db\TagMapper $tagMapper) {
-		$this->folderMapper = $folderMapper;
-		$this->bookmarkMapper = $bookmarkMapper;
-		$this->shareMapper = $shareMapper;
-		$this->sharedFolderMapper = $sharedFolderMapper;
+	public function __construct(
+		protected FolderMapper $folderMapper,
+		protected BookmarkMapper $bookmarkMapper,
+		protected ShareMapper $shareMapper,
+		protected SharedFolderMapper $sharedFolderMapper,
+		protected ICacheFactory $cacheFactory,
+		protected ContainerInterface $appContainer,
+		protected TagMapper $tagMapper
+	) {
 		$this->caches[self::CATEGORY_HASH] = $cacheFactory->createLocal('bookmarks:'.self::CATEGORY_HASH);
 		$this->caches[self::CATEGORY_SUBFOLDERS] = $cacheFactory->createLocal('bookmarks:'.self::CATEGORY_SUBFOLDERS);
+		$this->caches[self::CATEGORY_DELETED_SUBFOLDERS] = $cacheFactory->createLocal('bookmarks:'.self::CATEGORY_DELETED_SUBFOLDERS);
 		$this->caches[self::CATEGORY_FOLDERCOUNT] = $cacheFactory->createLocal('bookmarks:'.self::CATEGORY_FOLDERCOUNT);
 		$this->caches[self::CATEGORY_CHILDREN] = $cacheFactory->createLocal('bookmarks:'.self::CATEGORY_CHILDREN);
 		$this->caches[self::CATEGORY_CHILDREN_LAYER] = $cacheFactory->createLocal('bookmarks:'.self::CATEGORY_CHILDREN_LAYER);
 		$this->caches[self::CATEGORY_CHILDORDER] = $cacheFactory->createLocal('bookmarks:'.self::CATEGORY_CHILDORDER);
-		$this->appContainer = $appContainer;
-		$this->tagMapper = $tagMapper;
 	}
 
 
@@ -128,7 +112,7 @@ class TreeCacheManager implements IEventListener {
 	 */
 	public function set(string $category, string $type, int $id, $data) {
 		$key = $this->getCacheKey($type, $id);
-		return $this->caches[$category]->set($key, $data, 60 * 60 * 24);
+		return $this->caches[$category]->set($key, $data, self::TTL);
 	}
 
 	/**
