@@ -38,16 +38,21 @@ export default {
 			dropTargetEntered = 0
 			drop(e)
 			el.classList.remove('dropTarget--active')
+			const targets = document.querySelectorAll('.dropTarget--available')
+			targets.forEach(el => {
+				el.classList.remove('dropTarget--available')
+			})
+		})
+		window.document.body.addEventListener('dragend', (e) => {
+			const targets = document.querySelectorAll('.dropTarget--available')
+			targets.forEach(el => {
+				el.classList.remove('dropTarget--available')
+			})
 		})
 		window.document.body.addEventListener('dragstart', (e) => {
 			if (allowDrop(e)) {
 				el.classList.add('dropTarget--available')
 			}
 		})
-		window.document.body.addEventListener('dragend', (e) => {
-			if (allowDrop(e)) {
-				el.classList.remove('dropTarget--available')
-			}
-		})
 	},
 }
